/*
 * @rockStandardTools.java Version 1.1 11/06/2007
 *
 * Copyright (c) 2007 Kansas Geological Survey
 * 1930 Constant Avenue, Lawrence, Kansas, 66047, U.S.A.
 * All Rights Reserved.
 */

package rock;

/** Class rockStandardTools
 *  <p> This Class holds the standard tool information to map the LAS rock
 *      curves to standard names for plotting.
 */

public class rockStandardTools
{
  // Depth
  public static final int _TOP      = 0;
  public static final int _BASE     = 1;
  public static final int _CORR     = 2;
  // Descriptions
  public static final int _STU      = 3;
  public static final int _STN      = 4;
  public static final int _ENV      = 5;
  public static final int _LITHO    = 6;
  // Rock & Core Porosity
  public static final int _PCORE    = 7;
  public static final int _PPLUG    = 8;
  public static final int _P800     = 9;
  public static final int _PINSI    = 10;
  public static final int _PEFF     = 11;
  // Rock Permeability
  public static final int _KMAX     = 12;
  public static final int _K90      = 13;
  public static final int _KVRT     = 14;
  public static final int _KPLG     = 15;
  public static final int _KKL      = 16;
  public static final int _KINSI    = 17;
  public static final int _KKLIN    = 18;
  public static final int _KPVRT    = 19;
  // Saturation
  public static final int _SOIL     = 20;
  public static final int _SW       = 21;
  // Density
  public static final int _GMCC     = 22;
  public static final int _RHOD     = 23;
  public static final int _RHOW     = 24;
  // Archie Constants
  public static final int _MAMB     = 25;
  public static final int _MINSI    = 26;
  public static final int _NAMB     = 27;
  public static final int _NINSI    = 28;
  // KGS Misc
  public static final int _LTHCD    = 29;
  public static final int _FRACTURE = 30;
  // Gamma Ray
  public static final int _GR       = 31;
  public static final int _CGR      = 32;
  public static final int _PGR      = 33;
  public static final int _TH       = 34;
  public static final int _U        = 35;
  public static final int _K        = 36;
  // UNKNOWN Linear Curve
  public static final int _LIN_1    = 37;
  public static final int _LIN_2    = 38;
  public static final int _LIN_3    = 39;
  public static final int _LIN_4    = 40;
  // UNKNOWN Semilog Curve
  public static final int _LOG_1    = 41;
  public static final int _LOG_2    = 42;
  public static final int _LOG_3    = 43;
  public static final int _LOG_4    = 44;
  // Spectral Gamma Ray Ratios
  public static final int _THU      = 45;
  public static final int _THK      = 46;
  // Lithology Variables
  public static final int _GRL      = 47;
  public static final int _RHOG     = 48;
  public static final int _PHI      = 49;
  // TOTALS
  public static final int TOTAL_DATA = 45;
  public static final int TOTAL      = 50;

  public static final String ROCK_TOOLS[][] =
  {{ "TOP",      "Depth Top",                "F", "TOP", "0.0", "0.0", "KGS_D0" },
   { "BASE",     "Depth Bottom",             "F", "BASE", "0.0", "0.0", "KGS_D1" },
   { "CORR",     "Depth Correction",         "F", "CORR", "0.0", "0.0", "KGS_D2" },

   { "STU",      "Stratigraphic Unit",       "", "STU",   "0.0", "0.0", "STU" },
   { "STN",      "Stratigraphic Name",       "", "STN",   "0.0", "0.0", "STN" },
   { "ENV",      "Depositional Environment", "", "ENV",   "0.0", "0.0", "ENV" },
   { "LITHO",    "Lithofacies",              "", "LITHO", "0.0", "0.0", "LITHO" },

   { "PCORE",    "Whole Core Porosity",        "PU", "PHI", "-.1", ".3", "KGS_P0" },
   { "PPLUG",    "Core Plug Porosity Routine", "PU", "PHI", "-.1", ".3", "KGS_P1" },
   { "P800",     "Core Plug Porosity 800 PSI", "PU", "PHI", "-.1", ".3", "KGS_P2" },
   { "PINSI",    "Core Plug Porosity Insitu",  "PU", "PHI", "-.1", ".3", "KGS_P3" },
   { "PEFF",     "Effective Rock Porosity",    "PU", "PHI", "-.1", ".3", "KGS_P4" },

   { "KMAX",     "Whole Core Permeability Maximum",   "MD", "K", "0.01", "1000.0", "KGS_K0" },
   { "K90",      "Whole Core Permeability 90 deg",    "MD", "K", "0.01", "1000.0", "KGS_K1" },
   { "KVRT",     "Whole Core Permeability Vertical",  "MD", "K", "0.01", "1000.0", "KGS_K2" },
   { "KPLG",     "Core Plug Permeability Routine",    "MD", "K", "0.01", "1000.0", "KGS_K3" },
   { "KKL",      "Core Plug Permeability KL Routine", "MD", "K", "0.01", "1000.0", "KGS_K4" },
   { "KINSI",    "Core Plug Permeability Insitu",     "MD", "K", "0.01", "1000.0", "KGS_K5" },
   { "KKLIN",    "Core Plug Permeability KL Insitu",  "MD", "K", "0.01", "1000.0", "KGS_K6" },
   { "KPVRT",    "Core Plug Permeability Vertical",   "MD", "K", "0.01", "1000.0", "KGS_K7" },

   { "SOIL",     "Oil Saturation",              "PU", "SOIL", "0.0", "50.0", "KGS_S0" },
   { "SW",       "Water Saturation",            "PU", "SW", "0.0", "80.0", "KGS_S1" },

   { "GMCC",     "Grain Density (gm/cc)",       "GMCC", "GMCC", "2", "3", "KGS_G0" },
   { "RHOD",     "Density of Rock Dry (gm/cc)", "GMCC", "GMCC", "2", "3", "KGS_G1" },
   { "RHOW",     "Density of Rock Wet (gm/cc)", "GMCC", "GMCC", "2", "3", "KGS_G2" },

   { "MAMB",     "Archie Cementation Ambient", "FRAC", "M", "0.0", "4.0", "KGS_A0" },
   { "MINSI",    "Archie Cementation Insitu",  "FRAC", "M", "0.0", "4.0", "KGS_A1" },
   { "NAMB",     "Archie Saturation Ambient",  "FRAC", "N", "0.0", "4.0", "KGS_A2" },
   { "NINSI",    "Archie Saturation Insitu",   "FRAC", "N", "0.0", "4.0", "KGS_A3" },

   { "LTHCD",    "Lithofacies Code",           "LU",   "LTHCD", "0", "10", "KGS_O1" },
   { "FRACTURE", "Fractures",                  "", "FRACTURE", "0.0", "0.0", "KGS_O2" },

   { "GR",       "Gamma Ray",                  "API",  "GR",   "0.0", "150.0", "KGS_R0" },
   { "CGR",      "Gamma Ray Minus Uranium",    "API",  "CGR",  "0",   "150",   "KGS_R1" },
   { "PGR",      "Pseudo Gamma Ray",           "API",  "PGR",  "0",   "150",   "KGS_R2" },
   { "THOR",     "Thorium Concentration",      "PPM",  "SPGR", "-10", "30",    "KGS_R3" },
   { "URAN",     "Uranium Concentration",      "PPM",  "SPGR", "0",   "40",    "KGS_R4" },
   { "POTA",     "Potassium Concentration",    "%",    "SPGR", "-10", "5",     "KGS_R5" },

   { "LIN_1",    "Linear Track Curve 1",       "UNI", "LIN",   "0",    "1",    "KGS_UN0"  },
   { "LIN_2",    "Linear Track Curve 2",       "UNI", "LIN",   "0",    "1",    "KGS_UN1" },
   { "LIN_3",    "Linear Track Curve 3",       "UNI", "LIN",   "0",    "1",    "KGS_UN2" },
   { "LIN_4",    "Linear Track Curve 4",       "UNI", "LIN",   "0",    "1",    "KGS_UN3" },

   { "LOG_1",    "Semilog Track Curve 1",      "UNL", "LOG",   ".1",   "1000", "KGS_UN4" },
   { "LOG_2",    "Semilog Track Curve 2",      "UNL", "LOG",   ".1",   "1000", "KGS_UN5" },
   { "LOG_3",    "Semilog Track Curve 3",      "UNL", "LOG",   ".1",   "1000", "KGS_UN6" },
   { "LOG_4",    "Semilog Track Curve 4",      "UNL", "LOG",   ".1",   "1000", "KGS_UN7" },

   { "COMPUTED", "Th/U", "Thorium/Uranium Ratio",   "LOG_RATIO", ".1", "100", "KGS_CR1" },
   { "COMPUTED", "Th/K", "Thorium/Potassium Ratio", "LOG_RATIO", ".1", "100", "KGS_CR2" },

   { "COMPUTED", "Gamma Ray",                   "API",  "GR",   "0.0", "150.0", "KGS_CR0" },
   { "COMPUTED", "Grain Density (gm/cc)",       "GMCC", "GMCC", "2", "3", "KGS_CG" },
   { "COMPUTED", "Porosity",                    "PU", "PHI", "-.1", ".3", "KGS_CP" },
  };
}